==> am_mod_evt_0_2.zip: am_mod_evt_0_2/components/evt/template/barnraiser_01/inc/profile.tpl.inc.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
// 
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>


<?php
if (!empty($recommendations)) {
?>
<div class="box">
	<div class="box_top">
		<?php echo $lang['hdr_recommending'];?><br />
	</div>
	
	<div class="box_mid">
		<div class="content">
			<table border="0" cellspacing="0" cellpadding="2" width="100%">
			<?php
			foreach($recommendations as $key => $i):
			?>
			<tr>
				<td valign="top">
					<a href="index.php?amn=evt_item&amp;event_id=<?php echo $i['event_id'];?>"><b><?php echo $i['event_title'];?></b></a><br />
				</td>
				<td valign="top">
					<?php echo $i['event_synopsis'];?><br />
				</td>
			</tr>
			<?php
			endforeach;
			?>
			</table>
		</div>
	</div>
</div>
	
<div class="box_bottom">
	<span class="box_bottom_right"></span>
	<span class="box_bottom_left"></span>
</div>
<?php }?>


<div class="box">
	<div class="box_top">
		<?php echo $lang['hdr_participation'];?><br />
	</div>
	
	<div class="box_mid">
		<div class="content">
			<table width="100%" border="0" cellspacing="0" cellpadding="4">
				<tr>
					<td valign="top" width="50%">
						<b><?php echo $lang['txt_completed']; ?></b><br />
						<?php
						if (isset($events_done)) {
						?>
						<table border="0" cellspacing="" cellpadding="2" width="100%">
						<?php
						foreach($events_done as $key => $i):
						?>
						<tr>
							<td>
								<a href="index.php?amn=evt_item&amp;event_id=<?php echo $i['event_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file_md5_name_view']; ?>" class="picture"/></a>
							</td>
							<td valign="top">
								<a href="index.php?amn=evt_item&amp;event_id=<?php echo $i['event_id'];?>"><b><?php echo $i['event_title'];?></b></a><br />
								<?php echo $this->date->formatDate($i['event_start_datetime'],1);?><br />
								<?php echo $i['event_synopsis'];?>
							</td>
						</tr>
						<?php
						endforeach;
						?>
						</table>
						<?php }?>
					</td>
					<td valign="top">
						<b><?php echo $lang['txt_upcoming']; ?></b><br />
						<?php
						if (isset($events)) {
						?>
						<table border="0" cellspacing="0" cellpadding="2" width="100%">
						<?php
						foreach($events as $key => $i):
						?>
						<tr>
							<td>
								<a href="index.php?amn=evt_item&amp;event_id=<?php echo $i['event_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file_md5_name_view']; ?>" class="picture"/></a>
							</td>
							<td valign="top">
								<a href="index.php?amn=evt_item&amp;event_id=<?php echo $i['event_id'];?>"><b><?php echo $i['event_title'];?></b></a><br />
								<?php echo $this->date->formatDate($i['event_start_datetime'],1);?><br />
								<?php echo $i['event_synopsis'];?>
							</td>
						</tr>
						<?php
						endforeach;
						?>
						</table>
						<?php }?>
					</td>
				</tr>
			</table>
		</div>
	</div>
</div>
	
<div class="box_bottom">
	<span class="box_bottom_right"></span>
	<span class="box_bottom_left"></span>
</div>

==> am_mod_evt_0_4.zip: am_mod_evt_0_4/components/evt/template/barnraiser_01/inc/profile.tpl.inc.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
// 
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>


<?php
if (!empty($recommendations)) {
?>
<div class="box">
	<div class="box_top">
		<?php echo $lang['hdr_recommending'];?><br />
	</div>
	
	<div class="box_mid">
		<div class="content">
			<table border="0" cellspacing="0" cellpadding="2" width="100%">
			<?php
			foreach($recommendations as $key => $i):
			?>
			<tr>
				<td valign="top">
					<a href="index.php?amn=evt_item&amp;event_id=<?php echo $i['event_id'];?>"><b><?php echo $i['event_title'];?></b></a><br />
				</td>
				<td valign="top">
					<?php echo $i['event_synopsis'];?><br />
				</td>
			</tr>
			<?php
			endforeach;
			?>
			</table>
		</div>
	</div>
</div>
<?php }?>


<div class="box">
	<div class="box_top">
		<?php echo $lang['hdr_participation'];?><br />
	</div>
	
	<div class="box_mid">
		<div class="content">
			<table width="100%" border="0" cellspacing="0" cellpadding="4">
				<tr>
					<td valign="top" width="50%">
						<b><?php echo $lang['txt_completed']; ?></b><br />
						<?php
						if (isset($events_done)) {
						?>
						<table border="0" cellspacing="" cellpadding="2" width="100%">
						<?php
						foreach($events_done as $key => $i):
						?>
						<tr>
							<td>
								<a href="index.php?amn=evt_item&amp;event_id=<?php echo $i['event_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file_md5_name_view']; ?>" class="picture"/></a>
							</td>
							<td valign="top">
								<a href="index.php?amn=evt_item&amp;event_id=<?php echo $i['event_id'];?>"><b><?php echo $i['event_title'];?></b></a><br />
								<?php echo $this->date->formatDate($i['event_start_datetime'],1);?><br />
								<?php echo $i['event_synopsis'];?>
							</td>
						</tr>
						<?php
						endforeach;
						?>
						</table>
						<?php
						} else {
						?>
							<p>
								<?php echo $lang['template_error']['err_no_items'];?><br />
							</p>
						<?php }?>
					</td>
					<td valign="top">
						<b><?php echo $lang['txt_upcoming']; ?></b><br />
						<?php
						if (isset($events)) {
						?>
						<table border="0" cellspacing="0" cellpadding="2" width="100%">
						<?php
						foreach($events as $key => $i):
						?>
						<tr>
							<td>
								<a href="index.php?amn=evt_item&amp;event_id=<?php echo $i['event_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file_md5_name_view']; ?>" class="picture"/></a>
							</td>
							<td valign="top">
								<a href="index.php?amn=evt_item&amp;event_id=<?php echo $i['event_id'];?>"><b><?php echo $i['event_title'];?></b></a><br />
								<?php echo $this->date->formatDate($i['event_start_datetime'],1);?><br />
								<?php echo $i['event_synopsis'];?>
							</td>
						</tr>
						<?php
						endforeach;
						?>
						</table>
						<?php
						} else {
						?>
							<p>
								<?php echo $lang['template_error']['err_no_items'];?><br />
							</p>
						<?php }?>
					</td>
				</tr>
			</table>
		</div>
	</div>
</div>
